macro_rules! assert_lt {
($expected:expr, $actual:expr) => { ... };
($expected:expr, $actual:expr, $msg:expr) => { ... };
}Expand description
Asserts that the first expression is less than the second and short-circuits on failure.
macro_rules! assert_lt {
($expected:expr, $actual:expr) => { ... };
($expected:expr, $actual:expr, $msg:expr) => { ... };
}Asserts that the first expression is less than the second and short-circuits on failure.