macro_rules! expect_null {
($actual:expr) => { ... };
($actual:expr, $msg:expr) => { ... };
}Expand description
Asserts that the pointer is null, but does not short-circuit on failure.
macro_rules! expect_null {
($actual:expr) => { ... };
($actual:expr, $msg:expr) => { ... };
}Asserts that the pointer is null, but does not short-circuit on failure.