macro_rules! expect_ge {
($expected:expr, $actual:expr) => { ... };
($expected:expr, $actual:expr, $msg:expr) => { ... };
}Expand description
Asserts that the first expression is greater than or equal to the second, but does not short-circuit on failure.